#!/usr/bin/env python
# coding=utf-8
from setuptools import setup




setup(
    name='lylogger',
    version='0.1.0',
    author='GraySilver',
    author_email='allenyzx@163.com',
    url='https://github.com/GraySilver/Lylogger',
    description='This is a easy logger.',
    packages=['lylogger'],
    # install_requires=[
    #     "logging"
    # ],
    license='MIT',
    classifiers=[
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Text Processing :: Indexing",
        "Topic :: Utilities",
        "Topic :: Internet",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3.5",
    ],
)